--- a/Makefile
+++ b/Makefile
@@ -1,19 +1,19 @@
 
 src/hnb: src/*.c src/*.h src/*.inc src/hnbrc.inc
-	(cd src;make)
+	(cd src;$(MAKE))
 install: src/hnb
 	install -D src/hnb /usr/local/bin/hnb
 	install -D -m444 doc/hnb.1 /usr/local/man/man1/hnb.1
 clean:
-	(cd src;make clean)
-	(cd util;make clean)
+	(cd src;$(MAKE) clean)
+	(cd util;$(MAKE) clean)
 	rm -f *~
 
 rcupdate: updaterc
 updaterc: src/hnbrc.inc
 
 src/hnbrc.inc: doc/hnbrc
-	(cd util;make)
+	(cd util;$(MAKE))
 	echo -n "\"">src/hnbrc.inc
 	cat doc/hnbrc | util/asc2c >> src/hnbrc.inc
 	echo "\"">>src/hnbrc.inc
--- a/src/Makefile
+++ b/src/Makefile
@@ -1,5 +1,6 @@
-LIBS=-lncurses libcli/libcli.a
-CFLAGS=-I.. -Ilibcli -DHAVE_CONFIG_H -Wall -pedantic -g
+LIBS=$(shell ${PKG_CONFIG} --libs ncurses) libcli/libcli.a
+CFLAGS+=-Wall -pedantic
+CPPFLAGS+=-I.. -Ilibcli -DHAVE_CONFIG_H
 
 CFILES=$(wildcard *.c)
 OBJS=$(patsubst %.c,%.o,$(CFILES))
@@ -8,22 +9,22 @@
 	$(CC) -c $(CFLAGS) $(CPPFLAGS) -o $@ $<
 
 hnb: libcli/libcli.a Makefile $(OBJS) init_subsystems.c *.h *.inc
-	$(CC) -o hnb $(OBJS) $(LIBS) $(CFLAGS)
+	$(CC) -o hnb $(OBJS) $(LIBS) $(CFLAGS) $(LDFLAGS)
 #	strip hnb
 libcli/libcli.a: libcli/*.c
-	(cd libcli;make libcli.a)
+	(cd libcli;$(MAKE) libcli.a)
 libcli/libcli_p.a: libcli/*.c
-	(cd libcli;make libcli_p.a)
-init_subsystems.c: *.c
+	(cd libcli;$(MAKE) libcli_p.a)
+init_subsystems.c: $(CFILES)
 	echo "/* this file is autogenerated, do not edit */">init_subsystems.c
-	cat *.c | grep "^\!init_" | sort | sed -e "s/^\!/void /g">>init_subsystems.c
+	cat $(CFILES) | grep "^\!init_" | sort | sed -e "s/^\!/void /g">>init_subsystems.c
 	echo "">>init_subsystems.c
 	echo "void init_subsystems(){">>init_subsystems.c
-	cat *.c | grep "^\!init_" | sort | sed -e "s/^\!/ /g">>init_subsystems.c
+	cat $(CFILES) | grep "^\!init_" | sort | sed -e "s/^\!/ /g">>init_subsystems.c
 	echo "}">>init_subsystems.c
 clean:
 	rm -f xml_debug hnb $(OBJS) *~ cli_*.inc
-	(cd libcli;make clean)
+	(cd libcli;$(MAKE) clean)
 hnb_p: *.c libcli/libcli_p.a init_subsystems.c
 	$(CC) -o hnb_p *.c -pg -lncurses_p libcli/libcli_p.a -I.. -Ilibcli -DHAVE_CONFIG_H
 
--- a/src/libcli/Makefile
+++ b/src/libcli/Makefile
@@ -7,11 +7,11 @@
 clean:
 	rm -f *.o *.a *.so test-s* *~
 libcli.a: $(OBJS)
-	ar rc libcli.a cli*.o
+	$(AR) rc libcli.a cli*.o
 libcli_p.a: 
 	$(CC) -pg -c cli.c
 	$(CC) -pg -c cli_history.c
-	ar rcs libcli_p.a cli*.o
+	$(AR) rcs libcli_p.a cli*.o
 libcli.so: $(OBJS)
 	$(CC) -shared cli*.o -o libcli.so $(CFLAGS) $(LIBS)
 test-static: test.o libcli.a
